@@ -30,6 +30,7 @@
 class QPushButton;
 
 class KDoubleNumInput;
+class KAboutData;
 
 namespace Digikam
 {
@@ -51,9 +52,7 @@ public:
 protected:
 
     void solarize(double factor, uint *data, int w, int h);
-    
-    void closeEvent(QCloseEvent *e);
-    
+
 private:
     
     QWidget              *m_parent;
@@ -62,6 +61,8 @@ private:
 
     KDoubleNumInput      *m_numInput;
     
+    KAboutData           *m_about;
+    
     Digikam::ImageWidget *m_previewWidget;
 
 private slots:
