@@ -4,7 +4,7 @@
  * Date  : 2004-08-27
  * Description : 
  * 
- * Copyright 2004 by Gilles Caulier
+ * Copyright 2004-2005 by Gilles Caulier
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -34,7 +34,7 @@
 
 // Local includes.
 
-#include "unsharp.h"
+#include "imageeffect_unsharp.h"
 #include "imageplugin_unsharp.h"
 
 K_EXPORT_COMPONENT_FACTORY( digikamimageplugin_unsharp,
@@ -44,9 +44,9 @@ ImagePlugin_Unsharp::ImagePlugin_Unsharp(QObject *parent, const char*,
                                          const QStringList &)
                    : Digikam::ImagePlugin(parent, "ImagePlugin_Unsharp")
 {
-    new KAction(i18n("Unsharped Mask..."), "unsharpedmask", 0, 
-                this, SLOT(slotUnsharp()),
-                actionCollection(), "imageplugin_unsharp");
+    m_unsharpAction = new KAction(i18n("Unsharp Mask..."), "unsharpedmask", 0, 
+                          this, SLOT(slotUnsharp()),
+                          actionCollection(), "imageplugin_unsharp");
 
     setXMLFile("digikamimageplugin_unsharp_ui.rc");               
                     
@@ -57,9 +57,14 @@ ImagePlugin_Unsharp::~ImagePlugin_Unsharp()
 {
 }
 
+void ImagePlugin_Unsharp::setEnabledActions(bool enable)
+{
+    m_unsharpAction->setEnabled(enable);
+}
+
 void ImagePlugin_Unsharp::slotUnsharp()
 {
-    DigikamUnsharpFilterImagesPlugin::UnsharpDialog dlg(parentWidget());
+    DigikamUnsharpMaskImagesPlugin::ImageEffect_Unsharp dlg(parentWidget());
     dlg.exec();
 }
 
