@@ -4,7 +4,7 @@
  * Date  : 2004-08-27
  * Description : 
  * 
- * Copyright 2004 by Gilles Caulier
+ * Copyright 2004-2005 by Gilles Caulier
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -26,6 +26,8 @@
 
 #include <digikamheaders.h>
 
+class KAction;
+
 class ImagePlugin_Unsharp : public Digikam::ImagePlugin
 {
     Q_OBJECT
@@ -36,6 +38,12 @@ public:
                         const QStringList &args);
     ~ImagePlugin_Unsharp();
 
+    void setEnabledActions(bool enable);
+
+private:
+
+    KAction *m_unsharpAction;
+   
 private slots:
 
     void slotUnsharp();
