@@ -377,10 +377,6 @@ ImageEffect_WhiteBalance::ImageEffect_WhiteBalance(QWidget* parent, uint *imageD
 }
 
 ImageEffect_WhiteBalance::~ImageEffect_WhiteBalance()
-{
-}
-
-void ImageEffect_WhiteBalance::closeEvent(QCloseEvent *e)
 {
     m_histogramWidget->stopHistogramComputation();
 
@@ -388,7 +384,6 @@ void ImageEffect_WhiteBalance::closeEvent(QCloseEvent *e)
        delete [] m_destinationPreviewData;
        
     delete m_histogramWidget;
-    e->accept();
 }
 
 void ImageEffect_WhiteBalance::slotAutoAdjustExposure(void)
@@ -605,17 +600,17 @@ void ImageEffect_WhiteBalance::slotChannelChanged(int channel)
  
        case RedChannel:
           m_histogramWidget->m_channelType = Digikam::HistogramWidget::RedChannelHistogram;
-          m_hGradient->setColors( QColor( "red" ), QColor( "black" ) );
+          m_hGradient->setColors( QColor( "black" ), QColor( "red" ) );
           break;
 
        case GreenChannel:         
           m_histogramWidget->m_channelType = Digikam::HistogramWidget::GreenChannelHistogram;
-          m_hGradient->setColors( QColor( "green" ), QColor( "black" ) );
+          m_hGradient->setColors( QColor( "black" ), QColor( "green" ) );
           break;
 
        case BlueChannel:         
           m_histogramWidget->m_channelType = Digikam::HistogramWidget::BlueChannelHistogram;
-          m_hGradient->setColors( QColor( "blue" ), QColor( "black" ) );
+          m_hGradient->setColors( QColor( "black" ), QColor( "blue" ) );
           break;
        }
 
@@ -644,7 +639,7 @@ void ImageEffect_WhiteBalance::slotEffect()
     m_dark        = m_darkInput->value();
     m_black       = m_blackInput->value();
     m_exposition  = m_exposureInput->value();
-    m_gamma       = m_gammaInput->value();
+    m_gamma       = 2.0-m_gammaInput->value();
     m_saturation  = m_saturationInput->value();
     m_green       = m_greenInput->value();
     m_overExp     = m_overExposureIndicatorBox->isChecked();
@@ -682,7 +677,7 @@ void ImageEffect_WhiteBalance::slotOk()
     m_dark        = m_darkInput->value();
     m_black       = m_blackInput->value();
     m_exposition  = m_exposureInput->value();
-    m_gamma       = m_gammaInput->value();
+    m_gamma       = 2.0-m_gammaInput->value();
     m_saturation  = m_saturationInput->value();
     m_green       = m_greenInput->value();
     m_overExp     = false;
@@ -774,7 +769,7 @@ void ImageEffect_WhiteBalance::whiteBalance(uint *data, int width, int height)
             v = QMAX(rv[0], rv[1]);
             v = QMAX(v, rv[2]); 
             
-            if (m_clipSat) v = QMIN(v, (int)m_rgbMax);
+            if (m_clipSat) v = QMIN(v, (int)m_rgbMax-1);
             i = v;
 
             imagedata.channel.blue  = pixelColor(rv[0], i, v);
